readmet
=======

This module contains functions and objects for handling (mostly reading) less popular or vendor-specific data file formats used in meteorology and neighboring sciences.

Requirements:
-------------

    pip install numpy pandas

Installation:
-------------
As root or Administrator:

    pip install readmet

or as normal user: 

    pip install --user readmet

or manually install the sources 
available from [GitHub](https://github.com/cdruee/python-readmet)

Documentation: 
--------------
See <http://druee.gitlab-pages.uni-trier.de/python-readmet/>

